This repository contains tools to perform coarse grained simulations in OpenMM.  This repository also enables the use of coarse grained models with OpenMM utilities such as Yank.

Web-based documentation for this software is available via 'readthedocs':
https://cg-openmm.readthedocs.io/en/latest/

## To use this repository install it using standard Python conventions:

python setup.py install

## Dependencies:

For a detailed list of dependencies, and more detailed installation instructions, please read the "Installation notes" section of "manual.pdf".

## Testing your installation:

Test your installation by opening a new Python session and typing the following:

import cg_openmm

**For full documentation please refer to 'manual.pdf'.**


